# Bounded Minimisation Problems

This directory contains benchmark problems for bounded minimisation, where:
- The objective function returns a scalar value
- Variables have bounds (lower and/or upper limits)
- There are no additional equality or inequality constraints

All problems in this directory inherit from `AbstractBoundedMinimisation`.